@@ -1,5 +1,5 @@
 
-/* Ekiga -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
  * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs Opal and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the Opal program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -431,6 +431,7 @@ gnomemeeting_local_addressbook_get_contacts (GmAddressbook *addb,
 					     gchar *fullname,
 					     gchar *url,
 					     gchar *categorie,
+					     gchar *location,
 					     gchar *speeddial)
 {
   gchar *key = NULL;
@@ -525,7 +526,7 @@ gnomemeeting_local_addressbook_get_contacts (GmAddressbook *addb,
     for (aid = 1; aid <= max_aid; aid++) {
       addb_loop = get_addressbook (aid);
       if (addb_loop != NULL)
-	result = g_slist_concat (result, gnomemeeting_local_addressbook_get_contacts (addb_loop, nbr, partial_match, fullname, url, categorie, speeddial));
+	result = g_slist_concat (result, gnomemeeting_local_addressbook_get_contacts (addb_loop, nbr, partial_match, fullname, url, categorie, location, speeddial));
     }
   }
 
