@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs Opal and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the Opal program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -36,6 +36,8 @@
  *
  */
 
+#include "../../config.h"
+
 #include <dbus/dbus-glib.h>
 
 #include "dbus.h"
@@ -652,13 +654,13 @@ dbus_component_claim_ownership (DbusComponent *self)
                                          "org.freedesktop.DBus");
 
   if (!dbus_g_proxy_call (bus_proxy, "RequestName", &error,
-                          G_TYPE_STRING, "net.ekiga.instance",
+                          G_TYPE_STRING, "net." PACKAGE_NAME ".instance",
                           G_TYPE_UINT, DBUS_NAME_FLAG_DO_NOT_QUEUE,
                           G_TYPE_INVALID,
                           G_TYPE_UINT, &request_name_result,
                           G_TYPE_INVALID)) {
 
-    PTRACE (1, "Couldn't get the net.ekiga.instance name : "
+    PTRACE (1, "Couldn't get the net." PACKAGE_NAME ".instance name : "
 	    << error->message);
     return FALSE;
   }
@@ -744,7 +746,7 @@ gnomemeeting_dbus_component_call (GObject *obj,
     return;
 
   dbus_object = dbus_g_proxy_new_for_name (bus,
-					   "net.ekiga.instance",
+					   "net." PACKAGE_NAME ".instance",
 					   "/net/ekiga/instance",
 					   "net.ekiga.calls");
 
@@ -756,3 +758,31 @@ gnomemeeting_dbus_component_call (GObject *obj,
                               G_TYPE_INVALID);
 
 }
+
+void
+gnomemeeting_dbus_component_account_registration (GObject *obj,
+						  const gchar *username,
+						  const gchar *domain,
+						  gboolean registered)
+{
+  DbusComponent *self = DBUS_COMPONENT_OBJECT (obj);
+  GSList *accounts = NULL;
+  GSList *iter = NULL;
+  GmAccount *account = NULL;  
+
+  accounts = gnomemeeting_get_accounts_list ();
+
+  for (iter = accounts; iter != NULL; iter = iter->next) {
+
+    account = GM_ACCOUNT (iter->data);
+    if (!strcmp (account->domain, domain)
+	&& !strcmp (account->username, username)) {
+
+      g_signal_emit (self, signals[ACCOUNT_STATE], 0, account->aid,
+		     registered?REGISTERED:UNREGISTERED);
+    }
+  }
+
+  g_slist_foreach (accounts, (GFunc) gm_account_delete, NULL);
+  g_slist_free (accounts);
+}
