@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -188,15 +188,26 @@ static void add_account_cb (GtkWidget *button,
 
 
 /* DESCRIPTION  :  This callback is called when the user chooses to edit
- * 		   an account.
+ * 		   an account using the properties button.
  * BEHAVIOR     :  It runs the edit account dialog until the user validates
  * 		   it with correct data.
- * PRE          :  /
+ * PRE          :  The accounts window GMObject.
  */
-static void edit_account_cb (GtkWidget *button, 
+static void edit_account1_cb (GtkWidget *button, 
 			     gpointer data);
 
 
+/* DESCRIPTION  :  This callback is called when the user chooses to edit
+ * 		   an account by double-clicking on it.
+ * BEHAVIOR     :  It calls edit_account1_cb.
+ * PRE          :  The accounts window GMObject.
+ */
+static void edit_account2_cb (GtkTreeView *tree_view,
+			      GtkTreePath *arg1,
+			      GtkTreeViewColumn *arg2,
+			      gpointer data);
+
+
 /* DESCRIPTION  :  This callback is called when the user chooses to set
  * 		   an account as default.
  * BEHAVIOR     :  It sets it as default, only one default at a time.
@@ -275,8 +286,12 @@ gm_aw_from_string_to_account (gchar *str)
       account->enabled = atoi (couple [0]);
     if (size >= 2 && couple [1])
       account->default_account = atoi (couple [1]);
-    if (size >= 3 && couple [2])
+    if (size >= 3 && couple [2]) {
+
+      if (account->aid)
+	g_free (account->aid);
       account->aid = g_strdup (couple [2]);
+    }
     if (size >= 4 && couple [3])
       account->account_name = g_strdup (couple [3]);
     if (size >= 5 && couple [4])
@@ -358,9 +373,15 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
   GtkWidget *table = NULL;
   GtkWidget *label = NULL;
 
-  PRegularExpression regex ("^[a-z0-9][-._a-z0-9 ]*$", 
+  PRegularExpression regex ("^[a-z0-9][-._a-z0-9@ ]*$", 
 			    PRegularExpression::IgnoreCase);
 
+  /* FIXME: that catches the most common allowed characters only, for anything else,
+   * we will need a function to encode to % HEX HEX format for use in an URL or similar
+   */
+  PRegularExpression regex_username ("^[-._a-z0-9@ ][-._a-z0-9@ ]*$",
+		                     PRegularExpression::IgnoreCase);
+
   PString username;
   PString auth_username;
   PString host;
@@ -452,8 +473,8 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
   if (account && account->host)
     gtk_entry_set_text (GTK_ENTRY (aew->host_entry), account->host);
 
-  /* User Name */
-  label = gtk_label_new (_("User Name:"));
+  /* User */
+  label = gtk_label_new (_("User:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   aew->username_entry = gtk_entry_new ();
   gtk_size_group_add_widget (size_group_label, label);
@@ -568,7 +589,7 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
       /* Check at least an account name, registrar, 
        * and username are provided */
       if (protocol == 0) // SIP
-	valid = (username.FindRegEx (regex) != P_MAX_INDEX
+	valid = (username.FindRegEx (regex_username) != P_MAX_INDEX
 		 && account_name.FindRegEx (regex) != P_MAX_INDEX);
       else // H323
 	valid = (account_name.FindRegEx (regex) != P_MAX_INDEX);
@@ -592,15 +613,23 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
 	account->username = g_strdup (username);
 	
 	if (!strcmp (domain, ""))
-	  if (protocol == 0) // SIP
-	    account->domain = g_strdup (host);
+	  if (protocol == 0) { // SIP
+	    if (PString(username).Find("@") != P_MAX_INDEX)
+	      account->domain = g_strdup (SIPURL(username).GetHostName());
+	    else
+	      account->domain = g_strdup (host);
+	  }
 	  else
 	    account->domain = g_strdup ("");
 	else
 	  account->domain = g_strdup (domain);
 
-	if (!strcmp (auth_username, ""))
-	  account->auth_username = g_strdup (username);
+	if (!strcmp (auth_username, "")) {
+	  if (PString(username).Find("@") != P_MAX_INDEX)
+	    account->auth_username = g_strdup (SIPURL(username).GetUserName());
+	  else
+	    account->auth_username = g_strdup (account->username);
+	}
 	else
 	  account->auth_username = g_strdup (auth_username);
 
@@ -821,13 +850,15 @@ add_account_cb (GtkWidget *button,
 
 
 static void
-edit_account_cb (GtkWidget *button, 
+edit_account1_cb (GtkWidget *button, 
 		 gpointer data)
 {
   GmAccount *account = NULL;
   GtkWidget *accounts_window = NULL;
 
-  accounts_window = GnomeMeeting::Process ()->GetAccountsWindow (); 
+  g_return_if_fail (data != NULL);
+
+  accounts_window = GTK_WIDGET (data);
 
   account = gm_aw_get_selected_account (accounts_window);
   gm_aw_edit_account_dialog_run (GTK_WIDGET (accounts_window), 
@@ -837,6 +868,19 @@ edit_account_cb (GtkWidget *button,
 }
 
 
+static void
+edit_account2_cb (GtkTreeView *tree_view,
+		  GtkTreePath *arg1,
+		  GtkTreeViewColumn *arg2,
+		  gpointer data)
+{
+  g_return_if_fail (data != NULL);
+
+  edit_account1_cb (NULL, data);
+}
+
+
+
 static void
 set_account_as_default_cb (GtkWidget *button, 
 			   gpointer data)
@@ -907,7 +951,7 @@ gm_account_new ()
 
   account = g_new (GmAccount, 1);
 
-  account->aid = g_strdup (OpalGloballyUniqueID ().AsString ());
+  account->aid = g_strdup ((const char *) OpalGloballyUniqueID ().AsString ());
   account->account_name = NULL;
   account->protocol_name = NULL;
   account->host = NULL;
@@ -1434,6 +1478,8 @@ gm_accounts_window_new ()
     gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (aw->accounts_list), TRUE);
   gtk_tree_view_set_reorderable (GTK_TREE_VIEW (aw->accounts_list), TRUE);
+  g_signal_connect (G_OBJECT (aw->accounts_list), "row-activated",
+		    G_CALLBACK (edit_account2_cb), window); 
 
   renderer = gtk_cell_renderer_toggle_new ();
   column = gtk_tree_view_column_new_with_attributes (_("A"),
@@ -1534,7 +1580,7 @@ gm_accounts_window_new ()
   gtk_widget_set_sensitive (aw->edit_button, FALSE);
   gtk_box_pack_start (GTK_BOX (buttons_vbox), aw->edit_button, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (aw->edit_button), "clicked", 
-  		    GTK_SIGNAL_FUNC (edit_account_cb), NULL); 
+  		    GTK_SIGNAL_FUNC (edit_account1_cb), window); 
   
   aw->default_button = gtk_button_new_with_mnemonic (_("_Default"));
   gtk_widget_set_sensitive (aw->default_button, FALSE);
@@ -1570,14 +1616,13 @@ gm_accounts_window_new ()
 void
 gm_accounts_window_update_account_state (GtkWidget *accounts_window,
 					 gboolean refreshing,
-					 const gchar *domain,
+					 const gchar *hostname,
 					 const gchar *user,
 					 const gchar *status,
 					 const gchar *voicemails)
 {
-  OpalTransportAddress addr1;
-  OpalTransportAddress addr2;
-  
+  OpalTransportAddress addr;
+
   GtkTreeModel *model = NULL;
 
   GtkTreeIter iter;
@@ -1592,7 +1637,7 @@ gm_accounts_window_update_account_state (GtkWidget *accounts_window,
 
   g_return_if_fail (accounts_window != NULL);
   g_return_if_fail (user != NULL);
-  g_return_if_fail (domain != NULL);
+  g_return_if_fail (hostname != NULL);
 
   aw = gm_aw_get_aw (accounts_window);
 
@@ -1609,10 +1654,14 @@ gm_accounts_window_update_account_state (GtkWidget *accounts_window,
 			  COLUMN_ACCOUNT_USERNAME, &username,
 			  -1);
 
-      if (((host && domain && !strcmp (host, domain))
-	   || (realm && domain && !strcmp (realm, domain)))
-	  && (username && user && !strcmp (username, user))) {
-	
+      if (host)
+	addr = OpalTransportAddress (host);
+
+      if (((host && hostname && !strcmp (host, hostname)
+	    || !strcmp (addr.GetHostName (), hostname))
+	   || (realm && hostname && !strcmp (realm, hostname)))
+	  && (username && user && (!strcmp (SIPURL(username).GetUserName(), user) || !strcmp (username, user)))) {
+
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 			    COLUMN_ACCOUNT_STATE, refreshing, -1);
 	if (status)
