@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -317,6 +317,7 @@ gm_chw_update (GtkWidget *calls_history_window)
   gchar **call_data = NULL;
   
   GSList *calls_list = NULL;
+  GSList *calls_list_iter = NULL;
 
   chw = gm_chw_get_chw (calls_history_window);
 
@@ -330,9 +331,10 @@ gm_chw_update (GtkWidget *calls_history_window)
     
     calls_list = gm_conf_get_string_list (conf_key);
 
-    while (calls_list && calls_list->data) {
+    calls_list_iter = calls_list;
+    while (calls_list_iter && calls_list_iter->data) {
       
-      call_data = g_strsplit ((char *) calls_list->data, "|", 0);
+      call_data = g_strsplit ((char *) calls_list_iter->data, "|", 0);
       
       if (call_data) {
 	
@@ -350,10 +352,12 @@ gm_chw_update (GtkWidget *calls_history_window)
       
       g_strfreev (call_data);
 
-      calls_list = g_slist_next (calls_list);
+      calls_list_iter = g_slist_next (calls_list_iter);
     }
     
     g_free (conf_key);
+
+    g_slist_foreach (calls_list, (GFunc) g_free, NULL);
     g_slist_free (calls_list);
   }
 }
@@ -859,6 +863,8 @@ gm_calls_history_add_call (int i,
   gm_conf_set_string_list (conf_key, calls_list);
   
   g_free (conf_key);
+  
+  g_slist_foreach (calls_list, (GFunc) g_free, NULL);
   g_slist_free (calls_list);
 }
 
@@ -879,7 +885,8 @@ gm_calls_history_clear (int i)
 GSList *
 gm_calls_history_get_calls (int j,
 			    int n,
-			    gboolean unique)
+			    gboolean unique,
+			    gboolean reversed)
 {
   GmContact *contact = NULL;
 
@@ -893,7 +900,7 @@ gm_calls_history_get_calls (int j,
   gchar *conf_key = NULL;
 
   gboolean found = FALSE;
-  
+
   for (int i = 0 ; i < MAX_VALUE_CALL ; i++) {
 
     if (j == MAX_VALUE_CALL
@@ -902,12 +909,12 @@ gm_calls_history_get_calls (int j,
       conf_key = gm_chw_get_conf_key (i);
       calls_list = gm_conf_get_string_list (conf_key);
 
+      if (reversed) calls_list = g_slist_reverse (calls_list);
+
       calls_list_iter = calls_list;
       while (calls_list_iter && calls_list_iter->data) {
 
-	if ((j == MAX_VALUE_CALL && n != -1 
-	     && g_slist_position (calls_list, calls_list_iter) 
-	     > (int) g_slist_length (calls_list) - n)  
+	if ((j == MAX_VALUE_CALL && n != -1) 
 	    || (j == i)) {
 
 	  call_data = g_strsplit ((char *) calls_list_iter->data, "|", 0);
@@ -944,6 +951,8 @@ gm_calls_history_get_calls (int j,
 
       g_slist_foreach (calls_list, (GFunc) g_free, NULL);
       g_slist_free (calls_list);
+
+      g_free (conf_key);
     }
   }
 
@@ -953,10 +962,11 @@ gm_calls_history_get_calls (int j,
     result = work_list;
   else { // Return the last n results
 
+    if (reversed) work_list = g_slist_reverse (work_list);
     work_list_iter = work_list;
     while (work_list_iter && work_list_iter->data) {
 
-      if (g_slist_position (work_list, work_list_iter) > 
+      if (g_slist_position (work_list, work_list_iter) >=
 	  (int) g_slist_length (work_list) - n) {
 
 	result = 
@@ -969,6 +979,8 @@ gm_calls_history_get_calls (int j,
       work_list_iter = g_slist_next (work_list_iter);
     }
 
+    if (reversed) result = g_slist_reverse (result);
+
     g_slist_free (work_list);
   }
 
