@@ -1,5 +1,5 @@
 
-/* GnomeMeeting --  Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -98,13 +98,6 @@ enum {
 
 /* Declarations */
 
-/* DESCRIPTION  : /
- * BEHAVIOR     : Filters out "StaticPicture" from the list of available video
- *                input devices, since it requires further configuration.
- * PRE          : /
- */
-static char **get_filtered_video_devices_char_array (PStringArray devices);
-
 /* GUI functions */
 
 /* DESCRIPTION  : /
@@ -454,29 +447,6 @@ static void gnomemeeting_net_consult_cb (GtkWidget *,
 					 gpointer);
 
 
-static char **
-get_filtered_video_devices_char_array (PStringArray devices)
-{
-  PStringArray preresult;
-  char **unfiltered = NULL;
-  char **result = NULL;
-  int counter = 0;
-
-  unfiltered = devices.ToCharArray ();
-
-  for (counter = 0; unfiltered[counter]; counter++) {
-
-    if (strcmp ("StaticPicture", unfiltered[counter]))
-      preresult += PString (unfiltered[counter]);
-  }
-
-  free (unfiltered);
-
-  result = preresult.ToCharArray ();
-
-  return result;
-}
-
 static void 
 gm_dw_destroy (gpointer d)
 {
@@ -790,7 +760,7 @@ gm_dw_init_gnomemeeting_net_page (GtkWidget *druid_window,
 
 
   label = gtk_label_new (NULL);
-  text = g_strdup_printf ("<i>%s</i>", _("Your username and password are used to register to the ekiga.net SIP service. It will provide you a SIP address that you can give to your friends and family so that they can call you."));
+  text = g_strdup_printf ("<i>%s</i>", _("The username and password are used to login to your existing account at the ekiga.net free SIP service. If you do not have an ekiga.net SIP address yet, you may first create an account below. This will provide a SIP address that allows people to call you.\n\nYou may skip this step if you use an alternative SIP service, or if you would prefer to specify the login details later."));
   gtk_label_set_markup (GTK_LABEL (label), text);
   g_free (text);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
@@ -1891,7 +1861,7 @@ prepare_video_devices_page_cb (GnomeDruidPage *page,
   else 
     gtk_widget_set_sensitive (GTK_WIDGET (dw->video_test_button), TRUE);
   
-  array = get_filtered_video_devices_char_array (devices);
+  array = devices.ToCharArray ();
   gm_dw_option_menu_update (dw->video_device, array, video_recorder);
   free (array);
   
@@ -1989,21 +1959,17 @@ gm_druid_window_new ()
   GmDruidWindow *dw = NULL;
 
   GdkPixbuf *pixbuf = NULL;
-  gchar   *filename = NULL;
 
   
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   g_object_set_data_full (G_OBJECT (window), "window_name",
 			  g_strdup ("druid_window"), g_free); 
   
-  filename = g_build_filename (DATA_DIR, "pixmaps", PACKAGE_NAME ".png", NULL);
-  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-  g_free (filename);
-  if (pixbuf) {
-
-    gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
-    g_object_unref (pixbuf);
-  }
+  pixbuf = gtk_widget_render_icon (GTK_WIDGET (window),
+				   GM_STOCK_16,
+				   GTK_ICON_SIZE_MENU, NULL);
+  gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
+  g_object_unref (pixbuf);
 
   gtk_window_set_title (GTK_WINDOW (window), 
 			_("First Time Configuration Assistant"));
