@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -770,6 +770,11 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
 
   gchar **array = NULL;
 
+#ifndef DISABLE_GNOME
+  const char *backend = "gnome-vfs";
+#else
+  const char *backend = "gtk+";
+#endif
 
   pw = gm_pw_get_pw (prefs_window);
 
@@ -853,8 +858,9 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
 
   fsbutton =
-    gtk_file_chooser_button_new (_("Choose a sound"),
-				 GTK_FILE_CHOOSER_ACTION_OPEN);
+    gtk_file_chooser_button_new_with_backend (_("Choose a sound"),
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      backend);
   gtk_box_pack_start (GTK_BOX (hbox), fsbutton, TRUE, TRUE, 2);
 
   filefilter = gtk_file_filter_new ();
@@ -880,8 +886,8 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
 		    (gpointer) prefs_window);
 
   g_signal_connect (G_OBJECT (selection), "changed",
-      G_CALLBACK (sound_event_clicked_cb),
-      (gpointer) fsbutton);
+		    G_CALLBACK (sound_event_clicked_cb),
+		    (gpointer) fsbutton);
 
   button = gtk_button_new_with_label (_("Play"));
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
@@ -1023,19 +1029,14 @@ gm_pw_init_sip_page (GtkWidget *prefs_window,
   pw = gm_pw_get_pw (prefs_window);
 
   
-  /* Outbound Proxy */
-  subsection = gnome_prefs_subsection_new (prefs_window, container,
-					   _("SIP Outbound Proxy"), 3, 3);
-  
-  gnome_prefs_entry_new (subsection, _("_Outbound Proxy:"), SIP_KEY "outbound_proxy_host", _("The SIP Outbound Proxy to use for outgoing calls"), 0, false);
-
-  
   /* Add Misc Settings */
   subsection = gnome_prefs_subsection_new (prefs_window, container,
-					   _("Misc Settings"), 1, 2);
+					   _("Misc Settings"), 2, 2);
+
+  gnome_prefs_entry_new (subsection, _("_Outbound Proxy:"), SIP_KEY "outbound_proxy_host", _("The SIP Outbound Proxy to use for outgoing calls"), 0, false);
   
   entry =
-    gnome_prefs_entry_new (subsection, _("Forward _URL:"), SIP_KEY "forward_host", _("The host where calls should be forwarded if call forwarding is enabled"), 0, false);
+    gnome_prefs_entry_new (subsection, _("Forward _URL:"), SIP_KEY "forward_host", _("The host where calls should be forwarded if call forwarding is enabled"), 1, false);
   if (!strcmp (gtk_entry_get_text (GTK_ENTRY (entry)), ""))
     gtk_entry_set_text (GTK_ENTRY (entry), GMURL ().GetDefaultURL ());
 
@@ -1135,6 +1136,12 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
       NULL
     };
 
+#ifndef DISABLE_GNOME
+  const char *backend = "gnome-vfs";
+#else
+  const char *backend = "gtk+";
+#endif
+
 
   pw = gm_pw_get_pw (prefs_window); 
 
@@ -1172,8 +1179,10 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   /* The file selector button */
   label = gtk_label_new (_("Image:"));
   
-  button = gtk_file_chooser_button_new (_("Choose a Picture"),
-					GTK_FILE_CHOOSER_ACTION_OPEN);
+  button = 
+    gtk_file_chooser_button_new_with_backend (_("Choose a Picture"),
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      backend);
 
   preview_image_frame = gtk_frame_new (_("Preview"));
   preview_image = gtk_image_new ();
@@ -1194,6 +1203,11 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
 		    (gpointer) preview_image);
   
   conf_image = gm_conf_get_string (VIDEO_DEVICES_KEY "image");
+  if (!conf_image || (!strcmp (conf_image, ""))) {
+    g_free (conf_image);
+    conf_image = NULL;
+  }
+    
   if (conf_image)
     gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (button), conf_image);
   g_free (conf_image);
@@ -1453,11 +1467,16 @@ nat_method_update_cb (GtkWidget *widget,
 
 static void
 image_filename_browse_cb (GtkWidget *b, 
-	   gpointer data)
+			  gpointer data)
 {
   char *filename = NULL;
 
+  g_return_if_fail (data != NULL);
   filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (b));
+
+  if (filename == NULL)
+    return;
+  
   gm_conf_set_string ((gchar *) data, (gchar *) filename);
 
   g_free (filename);
